==> buildnotes-1.2.2-1.19-sources.jar: net/atif/buildnotes/gui/widget/TabButtonWidget.java <==
package net.atif.buildnotes.gui.widget;

import net.atif.buildnotes.gui.helper.Colors;
import net.atif.buildnotes.gui.helper.UIHelper;
import net.minecraft.class_2561;
import net.minecraft.class_310;
import net.minecraft.class_327;
import net.minecraft.class_4185;
import net.minecraft.class_4587;

public class TabButtonWidget extends class_4185 {

    private boolean isActive = false;

    public TabButtonWidget(int x, int y, int width, int height, class_2561 message, class_4241 onPress) {
        super(x, y, width, height, message, onPress);
    }

    @Override
    public void method_25359(class_4587 matrices, int mouseX, int mouseY, float delta) {
        // Determine the background color based on the button's state
        int color;
        if (this.isActive) {
            color = Colors.PANEL_BACKGROUND;
        } else if (this.method_25367()) {
            color = Colors.BUTTON_HOVER;
        } else {
            color = Colors.TAB_INACTIVE;
        }

        // Render the background
        method_25294(matrices, this.field_22760, this.field_22761, this.field_22760 + this.field_22758, this.field_22761 + this.field_22759, color);

        // Render the text
        class_327 textRenderer = class_310.method_1551().field_1772;
        method_27534(matrices, textRenderer, this.method_25369(), this.field_22760 + this.field_22758 / 2, this.field_22761 + (this.field_22759 - 8) / 2, Colors.TEXT_PRIMARY);
    }

    public boolean isActive() {
        return this.isActive;
    }

    public void setActive(boolean active) {
        this.isActive = active;
    }
}

==> buildnotes-1.2.2-1.20.2-sources.jar: net/atif/buildnotes/gui/widget/TabButtonWidget.java <==
package net.atif.buildnotes.gui.widget;

import net.atif.buildnotes.gui.helper.Colors;
import net.atif.buildnotes.gui.helper.UIHelper;
import net.minecraft.class_2561;
import net.minecraft.class_310;
import net.minecraft.class_327;
import net.minecraft.class_332;
import net.minecraft.class_4185;

public class TabButtonWidget extends class_4185 {

    private boolean isActive = false;

    public TabButtonWidget(int x, int y, int width, int height, class_2561 message, class_4241 onPress) {
        super(x, y, width, height, message, onPress, class_4185.field_40754);
    }

    @Override
    public void method_48579(class_332 context, int mouseX, int mouseY, float delta) {
        // Determine the background color based on the button's state
        int color;
        if (this.isActive) {
            color = Colors.PANEL_BACKGROUND;
        } else if (this.method_49606()) {
            color = Colors.BUTTON_HOVER;
        } else {
            color = Colors.TAB_INACTIVE;
        }

        // Render the background
        context.method_25294(this.method_46426(), this.method_46427(), this.method_46426() + this.field_22758, this.method_46427() + this.field_22759, color);

        // Render the text
        class_327 textRenderer = class_310.method_1551().field_1772;
        context.method_27534(textRenderer, this.method_25369(), this.method_46426() + this.field_22758 / 2, this.method_46427() + (this.field_22759 - 8) / 2, Colors.TEXT_PRIMARY);
    }

    public boolean isActive() {
        return this.isActive;
    }

    public void setActive(boolean active) {
        this.isActive = active;
    }
}
